<?php

namespace Drupal\views_private_access\Plugin\views\argument_validator;

use Drupal;
use Drupal\Core\Form\FormStateInterface;
use Drupal\user\Plugin\views\argument_validator\User;

/**
 * Validates whether user access is allowed.
 *
 * @ViewsArgumentValidator(
 *   id = "user_private",
 *   title = @Translation("User private"),
 *   entity_type = "user"
 * )
 */
class UserPrivate extends User {

  /**
   * {@inheritdoc}
   */
  public function buildOptionsForm(&$form, FormStateInterface $form_state) {
    parent::buildOptionsForm($form, $form_state);

    // Get list of permissions
    $perms = [];
    $permissions = Drupal::service('user.permissions')->getPermissions();
    foreach ($permissions as $perm => $perm_item) {
      $provider = $perm_item['provider'];
      $display_name = Drupal::moduleHandler()->getName($provider);
      $perms[$display_name][$perm] = strip_tags($perm_item['title']);
    }

    $form['perm'] = [
      '#type' => 'select',
      '#options' => $perms,
      '#title' => $this->t('Permission'),
      '#default_value' => $this->options['perm'] ?? NULL,
      '#description' => $this->t('Bypass the access check if the current user has this permission.'),
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function validateEntity(Drupal\Core\Entity\EntityInterface $entity) {
    $user = \Drupal::currentUser();
    if ($user->hasPermission('access all private views')) {
      return TRUE;
    }

    return parent::validateEntity($entity);
  }

}
